import {
	onLoad,
	onReady,
} from "@dcloudio/uni-app"
import {
	reactive,
	ref,
	computed,
	toRefs,
	onMounted,
	watch
} from "vue";
import {
	catchError,
	toast
} from "@/utils/common.js"
import * as httpUnit from "@/api/unitTest.js"
import cacheManager, {useXuekeNianji,useUnitTestTishi} from "@/utils/cacheManager.js"
	

function useJifen() {
	const data = reactive({
		rightAnswer: 0, // 答对
		wrongAnswer: 0, // 答错
		jifen: 0, // 积分
		zhangType: '' // 当前章类型  'last' 代表最后一章，最后一章无继续
	})

	function updateJifen({rightAnswer,wrongAnswer,jifen}) {
		data.rightAnswer = rightAnswer;
		data.wrongAnswer = wrongAnswer;
		data.jifen = jifen;
	}
	
	return {
		...toRefs(data),
		updateJifen
	}
}

export function useExam() {
	// 缓存
	const {getXueke} = useXuekeNianji();
	const { updateTishi, getTishi} = useUnitTestTishi();

	const {	showTishi, handleCloseTishi, handleShowTishi} = useTishiLeftRight()
	const {rightAnswer,wrongAnswer,jifen, updateJifen} = useJifen();

	
	const data = reactive({
		count: 0, // 已答题数
		total: 0, // 总题数
		current: 0, // 当前试题序列
		list: [], // 试题列表
		jieId: null, // 节Id
		zhangId: null,
		nianji: null,
		xueke: null,
	})
	onLoad((options) => {
		const { xueke } = getXueke();
		const {
			jieId,zhangId,nianji
		} = options;
		data.jieId = jieId; // 需要路由参数 节Id
		data.zhangId = zhangId;// 需要路由参数 章Id
		data.nianji = nianji; // 需要年纪Id 来执行返回页面
		data.xueke = xueke; // 需要年纪Id 来执行返回页面
	
		
		// 初始化页面数据
		initPage();
	})
	
	watch(() => data.list, (val) => {
		const list = data.list.filter(item => item.reply!==null);
		data.count = list.length;
	},{deep: true})


	// 初始化页面数据
	async function initPage() {
		const [err, cdata] = await catchError(httpUnit.getExamData({
			jieId: data.jieId
		}));
		if (err) {
			toast("单元测试数据获取异常");
			return;
		}
		refreshExam(cdata);
	}

	function formatListToUse(list) {
		list.forEach((item, index) => {
			item.mta_show = false;
			item.reply = null;
		})
	}

	// 数据赋值
	function refreshExam(list) {
		const cList = list;
		formatListToUse(cList)
		data.list = cList;
		data.total = cList.length;
		
		handleShowTishi();
	}

	// 交卷
	async function handleSubmit(dom) {
		const result = [];
		data.list.forEach(item => {
			result.push({reply: item.reply,stId: item.stId})
		})
		
		const [error, cdata] =await catchError(httpUnit.getExamSubmit(result));
		if (error) {
			toast("单元测试数据提交异常");
			return ;
		}
		dom.showPopup({
			right:cdata.dui,
			wrong:cdata.cuo,
			jifen:cdata.jifen
		});
	}



	return {
		...toRefs(data),
		rightAnswer,
		wrongAnswer,
		jifen,
		showTishi,

		handleSubmit,
		initPage,
		handleCloseTishi,
		handleShowTishi
	}
}

// 提示信息显示隐藏
function useTishiLeftRight() {
	
	const showTishi = ref(false);
	// 大鹅关闭追加缓存 --- 单独针对当前手机的缓存提示
	function handleCloseTishi() {
		updateTishi();
		showTishi.value = false;
	}
	// 大鹅显示追加缓存 --- 单独针对当前手机的缓存提示
	function handleShowTishi() {
		const isNotShow = Boolean(getTishi());
		showTishi.value = !isNotShow;
	}
	
	return {
		showTishi,
		handleCloseTishi,
		handleShowTishi
	}
}